@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-08-30'; # DATE
-our $VERSION = '1.59'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '1.60'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1013,8 +1013,8 @@ sub __gen_iter {
         };
     } else {
         # expect JSON stream for non-simple types
-        require JSON::MaybeXS;
-        state $json = JSON::MaybeXS->new->allow_nonref;
+        require JSON;
+        state $json = JSON->new->allow_nonref;
         my $i = -1;
         return sub {
             state $eof;
@@ -1247,8 +1247,8 @@ sub display_result {
                     print "\n" unless $type eq 'buf';
                 }
             } else {
-                require JSON::MaybeXS;
-                state $json = JSON::MaybeXS->new->allow_nonref;
+                require JSON;
+                state $json = JSON->new->allow_nonref;
                 while (defined(my $rec = $x->())) {
                     print $json->encode($rec), "\n";
                 }
@@ -1443,7 +1443,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.59 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-08-30.
+This document describes version 1.60 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-09-25.
 
 =head1 DESCRIPTION
 
@@ -2046,22 +2046,32 @@ C<$r> per-request stash/hash (see L</"REQUEST KEYS">).
 Passing the cmdline object can be useful, e.g. to call action_help(), to get the
 settings of the Perinci::CmdLine, etc.
 
+=head2 per_arg_json => bool
+
+This will be passed to L<Perinci::Sub::GetArgs::Argv>, which has this value
+default to 1.
+
+=head2 per_arg_yaml => bool (default: 1)
+
+This will be passed to L<Perinci::Sub::GetArgs::Argv>, which has this value
+default to 1.
+
 =head2 program_name => str
 
 Default is from PERINCI_CMDLINE_PROGRAM_NAME environment or from $0.
 
-=head2 riap_client => obj
-
-Set to Riap client instance, should you want to create one yourself. Otherwise
-will be set L<Perinci::Access> (in PC:Classic), or L<Perinci::Access::Lite> (in
-PC:Lite).
-
 =head2 riap_version => float (default: 1.1)
 
 Specify L<Riap> protocol version to use. Will be passed to Riap client
 constructor (unless you already provide a Riap client object, see
 C<riap_client>).
 
+=head2 riap_client => obj
+
+Set to Riap client instance, should you want to create one yourself. Otherwise
+will be set L<Perinci::Access> (in PC:Classic), or L<Perinci::Access::Lite> (in
+PC:Lite).
+
 =head2 riap_client_args => hash
 
 Arguments to pass to Riap client constructor. Will be used unless you create
@@ -2186,13 +2196,6 @@ default environment name is C<CPANDB_CPANMETA_OPT>.
 
 Whether to read configuration files.
 
-=head2 config_dirs => array of str
-
-Which directories to look for configuration file. The default is to look at the
-user's home and then system location. On Unix, it's C<< [ "$ENV{HOME}/.config",
-$ENV{HOME}, "/etc"] >>. If $ENV{HOME} is empty, getpwuid() is used to get home
-directory entry.
-
 =head2 config_filename => str|array[str]|array[hash]
 
 Configuration filename(s). The default is C<< program_name . ".conf" >>. For
@@ -2213,6 +2216,20 @@ can contain these keys: C<filename>, C<section>. For example:
 This means, configuration will be searched in C<mysuite.conf> under the section
 C<myapp1>, and then in C<myapp1.conf> in the default/global section.
 
+=head2 config_dirs => array of str
+
+Which directories to look for configuration file. The default is to look at the
+user's home and then system location. On Unix, it's C<< [ "$ENV{HOME}/.config",
+$ENV{HOME}, "/etc"] >>. If $ENV{HOME} is empty, getpwuid() is used to get home
+directory entry.
+
+=head2 cleanser => obj
+
+Object to cleanse result for JSON output. By default this is an instance of
+L<Data::Clean::JSON> and should not be set to other value in most cases.
+
+=head2 extra_urls_for_version => array of str
+
 =head2 skip_format => bool
 
 If set to 1, assume that function returns raw text that need not be translated,
