@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-08-30'; # DATE
-our $VERSION = '1.59'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '1.60'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -179,6 +179,36 @@ sub hook_after_parse_argv {
     }
 }
 
+# BEGIN_BLOCK: equal2
+sub equal2 {
+    state $require = do { require Scalar::Util };
+
+    # for lack of a better name, currently i name this 'equal2'
+    my ($val1, $val2) = @_;
+
+    # here are the rules:
+    # - if both are undef, 1
+    # - undef equals nothing else
+    # - if both are ref, equal if their refaddr() are equal
+    # - if only one is ref, 0
+    # - if none is ref, compare using eq
+
+    if (defined $val1) {
+        return 0 unless defined $val2;
+        if (ref $val1) {
+            return 0 unless ref $val2;
+            return Scalar::Util::refaddr($val1) eq Scalar::Util::refaddr($val2);
+        } else {
+            return 0 if ref $val2;
+            return $val1 eq $val2;
+        }
+    } else {
+        return 0 if defined $val2;
+        return 1;
+    }
+}
+# END_BLOCK: equal2
+
 sub hook_before_action {
     my ($self, $r) = @_;
 
@@ -224,7 +254,10 @@ sub hook_before_action {
             if ($res->[0]) {
                 die [400, "Argument '$arg' fails validation: $res->[0]"];
             }
-            $r->{args}{$arg} = $res->[1];
+            my $val0 = $r->{args}{$arg};
+            my $coerced_val = $res->[1];
+            $r->{args}{$arg} = $coerced_val;
+            $r->{args}{"-orig_$arg"} = $val0 unless equal2($val0, $coerced_val);
         }
 
         if ($meta->{args_rels}) {
@@ -471,7 +504,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.59 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-08-30.
+This document describes version 1.60 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-09-25.
 
 =head1 SYNOPSIS
 
